@@ -26,11 +26,13 @@
 #include <libanjuta/interfaces/ianjuta-debugger.h>
 #include <libanjuta/anjuta-plugin.h>
 
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
 
 typedef struct _Locals Locals;
 
 Locals *locals_new (DebugManagerPlugin *plugin);
 void locals_free (Locals *l);
 
+gchar* locals_find_variable_value (Locals *l, const gchar *name);
+
 #endif
