@@ -102,14 +102,13 @@ R7: Tool Storage
 /*---------------------------------------------------------------------------*/
 
 #define ICON_FILE "anjuta-tools-plugin-48.png"
-#define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-tools.ui"
+#define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-tools.xml"
 
 /*---------------------------------------------------------------------------*/
 
 struct _ATPPlugin {
 	AnjutaPlugin parent;
 	AnjutaPreferences *prefs;
-	GladeXML *gxml;
 	GtkActionGroup* action_group;
 	gint uiid;
 	ATPToolList list;
@@ -170,9 +169,8 @@ atp_plugin_activate (AnjutaPlugin *plugin)
 {
 	ATPPlugin *this = ANJUTA_PLUGIN_ATP (plugin);
 	AnjutaUI *ui;
-	GtkAction *action;
 	
-	DEBUG_PRINT ("Tools Plugin: Activating tools plugin...");
+	DEBUG_PRINT ("%s", "Tools Plugin: Activating tools plugin...");
 
 	/* Add all our actions */
 	ui = anjuta_shell_get_ui (plugin->shell, NULL);
@@ -205,7 +203,7 @@ atp_plugin_deactivate (AnjutaPlugin *plugin)
 	ATPPlugin *this = ANJUTA_PLUGIN_ATP (plugin);
 	AnjutaUI *ui;
 
-	DEBUG_PRINT ("Tools Plugin: Deactivating tools plugin...");
+	DEBUG_PRINT ("%s", "Tools Plugin: Deactivating tools plugin...");
 
 	atp_tool_list_deactivate (&this->list);	
 	atp_context_list_destroy (&this->context);
@@ -216,8 +214,6 @@ atp_plugin_deactivate (AnjutaPlugin *plugin)
 	ui = anjuta_shell_get_ui (plugin->shell, NULL);
 	anjuta_ui_unmerge (ui, this->uiid);
 
-	g_object_unref (this->gxml);
-
 	return TRUE;
 }
 
@@ -239,20 +235,26 @@ ipreferences_merge(IAnjutaPreferences* obj, AnjutaPreferences* prefs, GError** e
 {
 	/* Create the tools preferences page */
 	ATPPlugin* atp_plugin;
+	GtkBuilder *bxml = gtk_builder_new ();
+	GError* error = NULL;
 
 	atp_plugin = ANJUTA_PLUGIN_ATP (obj);
 	atp_plugin->prefs = anjuta_shell_get_preferences (ANJUTA_PLUGIN(obj)->shell,
 														NULL);
 
 	/* Load glade file */
-	atp_plugin->gxml = glade_xml_new (GLADE_FILE, "list_tools", NULL);
-	if (atp_plugin->gxml == NULL)
+	if (!gtk_builder_add_from_file (bxml, GLADE_FILE, &error))
+	{
+		g_warning ("Couldn't load builder file: %s", error->message);
+		g_error_free (error);
 		return;
+	}
 
-	atp_tool_dialog_show(&atp_plugin->dialog, atp_plugin->gxml);
+	atp_tool_dialog_show (&atp_plugin->dialog, bxml);
 
-	anjuta_preferences_add_page (atp_plugin->prefs, atp_plugin->gxml,
+	anjuta_preferences_add_from_builder (atp_plugin->prefs, bxml,
 									"Tools", _("Tools"), ICON_FILE);
+	g_object_unref (bxml);
 }
 
 static void
